@@ -35,7 +35,8 @@
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
 #ifdef SEARCH_FOR_UPDATES
-#include <QHttp>
+#include <QNetworkAccessManager>
+#include <QNetworkReply>
 #endif
 #include <QFile>
 #include <QSplitter>
@@ -43,10 +44,14 @@
 #include <QBuffer>
 #include <QLocale>
 #include <QMenu>
+#include <QDockWidget>
+#include <QMdiArea>
 
+#include "Folder.h"
 #include "Table.h"
 #include "ScriptingEnv.h"
 #include "Script.h"
+#include "SciDAVisObject.h"
 
 class QPixmap;
 class QCloseEvent;
@@ -54,10 +59,8 @@ class QDropEvent;
 class QTimerEvent;
 class QDragEnterEvent;
 class QTranslator;
-class QDockWidget;
 class QAction;
 class QActionGroup;
-class QWorkspace;
 class QLineEdit;
 class QTranslator;
 class QToolButton;
@@ -76,9 +79,6 @@ class Graph3D;
 class Note;
 class MultiLayer;
 class FunctionDialog;
-class Folder;
-class FolderListItem;
-class FolderListView;
 class Plot3DDialog;
 class MyWidget;
 class TableStatistics;
@@ -118,7 +118,7 @@ class AbstractAspect;
  * in ApplicationWindow after the above reorganizations. Think about whether a Model/View approach can be
  * used for Project/ProjectExplorer.
  */
-class ApplicationWindow: public QMainWindow, public scripted
+class ApplicationWindow: public SciDAVisObject<QMainWindow>, public scripted
 {
   Q_OBJECT
 public:
@@ -129,21 +129,22 @@ public:
   enum ShowWindowsPolicy{HideAll, ActiveFolder, SubFolders};
 
   QTranslator *appTranslator, *qtTranslator;
-  QDockWidget *logWindow;
-  QDockWidget *explorerWindow;
-  QTextEdit *results;
+  QDockWidget logWindow;
+  QDockWidget explorerWindow;
+  // TODO - convert to a statically owned member, but SIP currently requires it to be pointer
+  QTextEdit* results{new QTextEdit(&logWindow)};
 #ifdef SCRIPTING_CONSOLE
-  QDockWidget *consoleWindow;
-  QTextEdit *console;
+  QDockWidget consoleWindow;
+  QTextEdit console;
 #endif
-  QWorkspace* d_workspace;
+  QMdiArea d_workspace;
   QToolBar *file_tools, *graph_tools, *table_tools, *plot_tools, *graph_3D_tools, *edit_tools, *matrix_plot_tools;
-  FolderListView *lv;
-  FolderListView *folders;
+  FolderListView lv;
+  FolderListView folders;
   QToolButton *btnResults;
-  QWidgetList *hiddenWindows;
-  QWidgetList *outWindows;
-  QWidget *lastModified;
+  QList<MyWidget*> hiddenWindows;
+  QList<MyWidget*> outWindows;
+  MyWidget* lastModified;
 
 public:
   /*! Generates a new unique name starting with string /param name.
@@ -196,7 +197,7 @@ public slots:
   /// args are any argument to be passed to the script
   ApplicationWindow * loadScript(const QString& fn, const QStringList& args=QStringList(), bool execute = false);
 
-  QWidgetList * windowsList();
+  QList<MyWidget *> windowsList();
   void updateWindowLists(MyWidget *w);
   /*!
     Arranges all the visible project windows in a cascade pattern.
@@ -211,7 +212,7 @@ public slots:
   //! Set the project status to saved (not modified)
   void savedProject();
   //! Set the project status to modified and save 'w' as the last modified widget
-  void modifiedProject(QWidget *w);
+  void modifiedProject(MyWidget *w);
   //@}
 
   //! \name Settings
@@ -282,7 +283,7 @@ public slots:
   void newSurfacePlot();
   void editSurfacePlot();
   void remove3DMatrixPlots(Matrix *m);
-  void updateMatrixPlots(QWidget *);
+  void updateMatrixPlots(MyWidget *);
   void add3DData();
   void change3DData();
   void change3DData(const QString& colName);
@@ -363,7 +364,7 @@ public slots:
   Table* newHiddenTable(const QString& name, const QString& label, QList<Column *> columns);
   Table* table(const QString& name);
   Table* convertMatrixToTable();
-  QWidgetList* tableList();
+  QList<MyWidget*>* tableList();
 
   void connectTable(Table* w);
   void newWrksheetPlot(const QString& name,const QString& label, QList<Column *> columns);
@@ -389,7 +390,7 @@ public slots:
   void setGraphDefaultSettings(bool autoscale,bool scaleFonts,bool resizeLayers,bool antialiasing);
   void setLegendDefaultSettings(int frame, const QFont& font,
                                 const QColor& textCol, const QColor& backgroundCol);
-  void setArrowDefaultSettings(int lineWidth,  const QColor& c, Qt::PenStyle style,
+  void setArrowDefaultSettings(const QPen& pen,
                                int headLength, int headAngle, bool fillHead);
   void plotPie();
   void plotVectXYXY();
@@ -413,7 +414,7 @@ public slots:
   void exportAllGraphs();
   void exportPDF();
   void print();
-  void print(QWidget* w);
+  void print(MyWidget* w);
   void printAllPlots();
   //@}
 
@@ -442,7 +443,7 @@ public slots:
 
   void updateWindowStatus(MyWidget* );
 
-  bool hidden(QWidget* window);
+  bool hidden(MyWidget* window);
   void closeActiveWindow();
   void closeWindow(MyWidget* window);
 
@@ -451,8 +452,8 @@ public slots:
 
   void hideWindow(MyWidget* window);
   void hideActiveWindow();
-  void activateWindow();
-  void activateWindow(MyWidget *);
+  void activateSubWindow();
+  void activateSubWindow(MyWidget *);
   void printWindow();
   //@}
 
@@ -460,12 +461,13 @@ public slots:
   static void about();
   //! Return a version string ("SciDAVis x.y.z")
   static QString versionString();
+  static int qtVersion() {return QT_VERSION;}
   void windowsMenuAboutToShow();
   void windowsMenuActivated( bool );
   void removeCurves(const QString& name);
   QStringList dependingPlots(const QString& caption);
   QStringList depending3DPlots(Matrix *m);
-  QStringList multilayerDependencies(QWidget *w);
+  QStringList multilayerDependencies(MyWidget *w);
 
   void saveAsTemplate();
   void openTemplate();
@@ -528,9 +530,9 @@ public slots:
   void initToolBars();
   void initPlot3DToolBar();
   void disableActions();
-  void customToolBars(QWidget* w);
-  void customMenu(QWidget* w);
-  void windowActivated(QWidget *w);
+  void customToolBars(MyWidget* w);
+  void customMenu(MyWidget* w);
+  void windowActivated(QMdiSubWindow *w);
   //@}
 
   //! \name Table Tools
@@ -725,15 +727,15 @@ public slots:
   void pickPlotStyle( QAction* action );
   void pickCoordSystem( QAction* action);
   void pickFloorStyle( QAction* action);
-  void custom3DActions(QWidget *w);
+  void custom3DActions(MyWidget *w);
   void custom3DGrids(int grids);
   //@}
 
   void updateRecentProjectsList();
 
 #ifdef SEARCH_FOR_UPDATES
-  //!  connected to the done(bool) signal of the http object
-  void receivedVersionFile(bool error);
+  //!  connected to the finished(QNetworkReply*) signal of the http object
+  void receivedVersionFile(QNetworkReply*);
   //!  called when the user presses the actionCheckUpdates
   void searchForUpdates();
 #endif
@@ -760,7 +762,7 @@ public slots:
   bool projectHasMatrices();
 
   //! Returns a pointer to the window named "name"
-  QWidget* window(const QString& name);
+  MyWidget* window(const QString& name);
 
   //! Returns a list with the names of all the matrices in the project
   QStringList matrixNames();
@@ -929,7 +931,7 @@ public:
   bool d_extended_open_dialog;
   bool generateUniformFitPoints;
   bool generatePeakCurves;
-  int peakCurvesColor;
+  QColor peakCurvesColor;
   //! User defined size for the Add/Remove curves dialog
   QSize d_add_curves_dialog_size;
 
@@ -992,7 +994,7 @@ public:
   bool renameColumns, copiedLayer, strip_spaces, simplify_spaces;
   QStringList recentProjects;
   QStringList tableWindows();
-  bool saved, showPlot3DProjection, showPlot3DLegend, orthogonal3DPlots, autoscale3DPlots;
+  bool saved, showPlot3DProjection, showPlot3DLegend, orthogonal3DPlots=false, autoscale3DPlots;
   QStringList plot3DColors, locales;
   QStringList functions; //user-defined functions;
   QStringList xFunctions, yFunctions, rFunctions,thetaFunctions; // user functions for parametric and polar plots
@@ -1046,7 +1048,7 @@ private:
   bool validFor2DPlot(Table *table, int type);
 
   //! Workaround for the new colors introduced in rev 447
-  int convertOldToNewColorIndex(int cindex);
+  unsigned int convertOldToNewColorIndex(unsigned int cindex);
 
   //! Stores the pointers to the dragged items from the FolderListViews objects
   QList<QTreeWidgetItem *> draggedItems;
@@ -1055,9 +1057,9 @@ private:
 
 #ifdef SEARCH_FOR_UPDATES
   //! Used when checking for new versions
-  QHttp http;
+  QNetworkAccessManager http;
   //! Used when checking for new versions
-  QBuffer version_buffer;
+  QByteArray version_buffer;
 #endif
 
   Graph *lastCopiedLayer;
