@@ -1382,7 +1382,7 @@ void ConfigDialog::pickWorkspaceColor()
 
 void ConfigDialog::pickDataMaxColor()
 {
-	QColor c = QColorDialog::getColor(QColor(plot3DColors[0]), this );
+	QColor c = QColorDialog::getColor(QColor(COLORVALUE(plot3DColors[0])), this );
 	if ( !c.isValid() )
 		return;
 
@@ -1391,7 +1391,7 @@ void ConfigDialog::pickDataMaxColor()
 
 void ConfigDialog::pickDataMinColor()
 {
-	QColor c = QColorDialog::getColor(QColor(plot3DColors[4]), this );
+	QColor c = QColorDialog::getColor(QColor(COLORVALUE(plot3DColors[4])), this );
 	if ( !c.isValid() )
 		return;
 
@@ -1400,7 +1400,7 @@ void ConfigDialog::pickDataMinColor()
 
 void ConfigDialog::pick3DBackgroundColor()
 {
-	QColor c = QColorDialog::getColor(QColor(plot3DColors[7]), this );
+	QColor c = QColorDialog::getColor(QColor(COLORVALUE(plot3DColors[7])), this );
 	if ( !c.isValid() )
 		return;
 
@@ -1409,7 +1409,7 @@ void ConfigDialog::pick3DBackgroundColor()
 
 void ConfigDialog::pickMeshColor()
 {
-	QColor c = QColorDialog::getColor(QColor(plot3DColors[2]), this );
+	QColor c = QColorDialog::getColor(QColor(COLORVALUE(plot3DColors[2])), this );
 	if ( !c.isValid() )
 		return;
 
@@ -1418,7 +1418,7 @@ void ConfigDialog::pickMeshColor()
 
 void ConfigDialog::pickGridColor()
 {
-	QColor c = QColorDialog::getColor(QColor(plot3DColors[3]), this );
+	QColor c = QColorDialog::getColor(QColor(COLORVALUE(plot3DColors[3])), this );
 	if ( !c.isValid() )
 		return;
 
@@ -1427,7 +1427,7 @@ void ConfigDialog::pickGridColor()
 
 void ConfigDialog::pick3DAxesColor()
 {
-	QColor c = QColorDialog::getColor(QColor(plot3DColors[6]), this );
+	QColor c = QColorDialog::getColor(QColor(COLORVALUE(plot3DColors[6])), this );
 	if ( !c.isValid() )
 		return;
 
@@ -1436,7 +1436,7 @@ void ConfigDialog::pick3DAxesColor()
 
 void ConfigDialog::pick3DNumbersColor()
 {
-	QColor c = QColorDialog::getColor(QColor(plot3DColors[5]), this );
+	QColor c = QColorDialog::getColor(QColor(COLORVALUE(plot3DColors[5])), this );
 	if ( !c.isValid() )
 		return;
 
@@ -1445,7 +1445,7 @@ void ConfigDialog::pick3DNumbersColor()
 
 void ConfigDialog::pick3DLabelsColor()
 {
-	QColor c = QColorDialog::getColor(QColor(plot3DColors[1]), this );
+	QColor c = QColorDialog::getColor(QColor(COLORVALUE(plot3DColors[1])), this );
 	if ( !c.isValid() )
 		return;
 
