@@ -29,7 +29,7 @@
 #include "FitDialog.h"
 #include "MyParser.h"
 #include "ApplicationWindow.h"
-#include "ColorBox.h"
+#include "ColorButton.h"
 #include "Fit.h"
 #include "MultiPeakFit.h"
 #include "ExponentialFit.h"
@@ -63,7 +63,7 @@
 
 #define CONFS(string) QString::number(QLocale().toDouble(string),'g',boxPrecision->value())
 
-FitDialog::FitDialog( QWidget* parent, Qt::WFlags fl )
+FitDialog::FitDialog( QWidget* parent, Qt::WindowFlags fl )
 : QDialog( parent, fl )
 {
 	setWindowTitle(tr("Fit Wizard"));
@@ -114,13 +114,21 @@ void FitDialog::initFitPage()
 
 	boxParams = new QTableWidget();
     boxParams->setColumnCount(3);
+#if QT_VERSION >= 0x050000
+    boxParams->horizontalHeader()->setSectionsClickable(false);
+    boxParams->horizontalHeader()->setSectionResizeMode (0, QHeaderView::ResizeToContents);
+    boxParams->horizontalHeader()->setSectionResizeMode (1, QHeaderView::Stretch);
+    boxParams->horizontalHeader()->setSectionResizeMode (2, QHeaderView::ResizeToContents);
+    boxParams->verticalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
+#else
     boxParams->horizontalHeader()->setClickable(false);
     boxParams->horizontalHeader()->setResizeMode (0, QHeaderView::ResizeToContents);
     boxParams->horizontalHeader()->setResizeMode (1, QHeaderView::Stretch);
     boxParams->horizontalHeader()->setResizeMode (2, QHeaderView::ResizeToContents);
+    boxParams->verticalHeader()->setResizeMode(QHeaderView::ResizeToContents);
+#endif
     QStringList header = QStringList() << tr("Parameter") << tr("Value") << tr("Constant");
     boxParams->setHorizontalHeaderLabels(header);
-    boxParams->verticalHeader()->setResizeMode(QHeaderView::ResizeToContents);
     boxParams->verticalHeader()->hide();
     gl1->addWidget(boxParams, 3, 1);
 
@@ -132,9 +140,9 @@ void FitDialog::initFitPage()
     gl1->addWidget(boxAlgorithm, 4, 1);
 
 	gl1->addWidget(new QLabel( tr("Color")), 5, 0);
-	boxColor = new ColorBox();
-	boxColor->setColor(QColor(Qt::red));
-    gl1->addWidget(boxColor, 5, 1);
+	btnColor = new ColorButton();
+	btnColor->setColor(QColor(Qt::red));
+	gl1->addWidget(btnColor, 5, 1);
 
     QGroupBox *gb1 = new QGroupBox();
     gb1->setLayout(gl1);
@@ -1046,7 +1054,7 @@ void FitDialog::accept()
 	try
 	{
 		MyParser parser;
-		parser.SetExpr(CONFS(from).toAscii().constData());
+		parser.SetExpr(CONFS(from).toUtf8().constData());
 		start=parser.Eval();
 	}
 	catch(mu::ParserError &e)
@@ -1059,7 +1067,7 @@ void FitDialog::accept()
 	try
 	{
 		MyParser parser;
-		parser.SetExpr(CONFS(to).toAscii().constData());
+		parser.SetExpr(CONFS(to).toUtf8().constData());
 		end=parser.Eval();
 	}
 	catch(mu::ParserError &e)
@@ -1080,7 +1088,7 @@ void FitDialog::accept()
 	try
 	{
 		MyParser parser;
-		parser.SetExpr(CONFS(tolerance).toAscii().constData());
+		parser.SetExpr(CONFS(tolerance).toUtf8().constData());
 		eps=parser.Eval();
 	}
 	catch(mu::ParserError &e)
@@ -1203,7 +1211,7 @@ void FitDialog::accept()
 
         d_fitter->setTolerance (eps);
         d_fitter->setAlgorithm((Fit::Algorithm)boxAlgorithm->currentIndex());
-        d_fitter->setColor(boxColor->currentIndex());
+        d_fitter->setColor(btnColor->color());
         d_fitter->generateFunction(generatePointsBtn->isChecked(), generatePointsBox->value());
         d_fitter->setMaximumIterations(boxPoints->value());
         d_fitter->scaleErrors(scaleErrorsBox->isChecked());
@@ -1298,7 +1306,7 @@ bool FitDialog::validInitialValues()
 		try
 		{
 			MyParser parser;
-			parser.SetExpr(CONFS(boxParams->item(i,1)->text()).toAscii().constData());
+			parser.SetExpr(CONFS(boxParams->item(i,1)->text()).toUtf8().constData());
 			parser.Eval();
 		}
 		catch (mu::ParserError &e)
@@ -1319,7 +1327,7 @@ void FitDialog::changeDataRange()
 	boxTo->setText(QString::number(qMax(start, end), 'g', 15));
 }
 
-void FitDialog::setSrcTables(QWidgetList* tables)
+void FitDialog::setSrcTables(QList<MyWidget*>* tables)
 {
 	if (tables->isEmpty())
 	{
@@ -1389,4 +1397,3 @@ void FitDialog::resetFunction()
 	boxParam->clear();
 	editBox->clear();
 }
-
