@@ -38,7 +38,6 @@
 #include <qevent.h>
 #include <qpoint.h>
 #include <qmessagebox.h>
-#include <qmime.h>
 #include <qstringlist.h>
 #include <qapplication.h>
 #include <qcursor.h>
@@ -46,9 +45,10 @@
 #include <QKeyEvent>
 #include <QDropEvent>
 #include <QMouseEvent>
+#include <QDrag>
 
-Folder::Folder( Folder *parent, const QString &name )
-	: QObject(parent), d_active_window(0)
+Folder::Folder(const QString &name )
+	: d_active_window(0)
 {
 	QObject::setObjectName(name);
 	birthdate = QDateTime::currentDateTime ().toString(Qt::LocalDate);
@@ -255,8 +255,8 @@ void FolderListItem::setData( int column, int role, const QVariant& value)
  *
  *****************************************************************************/
 
-FolderListView::FolderListView( QWidget *parent, const QString name )
-	: QTreeWidget( parent ), mousePressed( false )
+FolderListView::FolderListView(const QString& name )
+	: mousePressed( false )
 {
     setObjectName(name.toLocal8Bit());
     setAcceptDrops( true );
@@ -264,39 +264,37 @@ FolderListView::FolderListView( QWidget *parent, const QString name )
     setDropIndicatorShown(true);
 }
 
-void FolderListView::startDrag()
+void FolderListView::startDrag(Qt::DropActions supportedActions)
 {
-QTreeWidgetItem *item = currentItem();
-if (!item)
-	return;
+  QTreeWidgetItem *item = currentItem();
+  if (!item)
+    return;
 
-if (item == topLevelItem(0) && item->treeWidget()->rootIsDecorated())
-	return;//it's the project folder so we don't want the user to move it
+  if (item == topLevelItem(0) && item->treeWidget()->rootIsDecorated())
+    return;//it's the project folder so we don't want the user to move it
 
-// Q3CHECK viewportToContents( viewport()->mapFromGlobal( QCursor::pos() ) );
+  QPixmap pix;
+  if (item->type() == FolderListItem::FolderType)
+    pix = QPixmap(":/folder_closed.xpm");
+  else
+    pix = item->icon(0).pixmap(QSize());
 
-QPixmap pix;
-if (item->type() == FolderListItem::FolderType)
-	pix = QPixmap(":/folder_closed.xpm");
-else
-	pix = item->icon(0).pixmap(QSize());
+  QDrag *drag = new QDrag(viewport());
+  drag->setPixmap(pix);
+  drag->setHotSpot(QPoint(pix.width()/2, pix.height()/2 ) );
 
-QDrag *drag = new QDrag(viewport());
-drag->setPixmap(pix);
-drag->setHotSpot(QPoint(pix.width()/2, pix.height()/2 ) );
+  QList<QTreeWidgetItem *> lst;
+  QTreeWidgetItemIterator it(this);
+  while (*it)
+    {
+      if ((*it)->isSelected())
+        lst.append(*it);
+      it++;
+    }
 
-QList<QTreeWidgetItem *> lst;
-QTreeWidgetItemIterator it(this);
-while (*it)
-	{
-	if ((*it)->isSelected())
-		lst.append(*it);
-	it++;
-	}
-
-emit dragItems(lst);
-	drag->setMimeData(mimeData(lst));
-	drag->exec();
+  emit dragItems(lst);
+  drag->setMimeData(mimeData(lst));
+  drag->exec(supportedActions);
 }
 
 void FolderListView::dropEvent( QDropEvent *e )
@@ -390,7 +388,7 @@ void FolderListView::mouseMoveEvent( QMouseEvent* e )
 if ( mousePressed && ( presspos - e->pos() ).manhattanLength() > QApplication::startDragDistance() )
 	{
 	mousePressed = false;
-	QTreeWidgetItem *item = itemAt( presspos ); // Q3CHECK contentsToViewport(presspos) );
+	QTreeWidgetItem *item = itemAt( presspos );
 	if ( item )
 		startDrag();
     }
