@@ -66,14 +66,18 @@ class QwtErrorPlotCurve;
 
 //! Structure containing curve layout parameters
 typedef struct{
-  int lCol;        //!< line color
+  unsigned int lCol; //!< line color
   int lWidth;      //!< line width
   int lStyle;      //!< line style
+  int lCapStyle=0;   //!< line CapStyle
+  int lJoinStyle=0x40;  //!< line JoinStyle
+  QString lCustomDash;
   int filledArea;  //!< flag: toggles area filling under curve
-  int aCol;        //!< curve area color
+  unsigned int aCol; //!< curve area color
   int aStyle;      //!< area filling style
-  int symCol;      //!< symbol outline color
-  int fillCol;     //!< symbol fill color
+  unsigned int symCol; //!< symbol outline color
+  bool symbolFill; //!< flag: toggles symbol filling
+  unsigned int fillCol; //!< symbol fill color
   int penWidth;    //!< symbol outline width
   int sSize;       //!< symbol size
   int sType;       //!< symbol type (shape)
@@ -116,7 +120,7 @@ class Graph: public QWidget
 	Q_OBJECT
 
 	public:
-		Graph (QWidget* parent=0, QString name=QString(), Qt::WFlags f=0);
+		Graph (QWidget* parent=0, QString name=QString(), Qt::WindowFlags f=0);
 		~Graph();
 
 		enum Axis{Left, Right, Bottom, Top};
@@ -373,7 +377,7 @@ public slots:
 		QVector<int> lineMarkerKeys(){return d_lines;};
 
 		//!Draws a line/arrow depending on the value of "arrow"
-		void drawLine(bool on, bool arrow = FALSE);
+		void drawLine(bool on, bool arrow = false);
 		bool drawArrow(){return drawArrowOn;};
 		bool drawLineActive(){return drawLineOn;};
 
@@ -640,6 +644,7 @@ public slots:
 		bool ignoresResizeEvents(){return ignoreResize;};
 		void setIgnoreResizeEvents(bool ok){ignoreResize=ok;};
 		void resizeEvent(QResizeEvent *e);
+		void hideEvent(QHideEvent *e);
 		void scaleFonts(double factor);
 		//@}
 
@@ -728,6 +733,7 @@ signals:
 		//! Render hint for plot items.
 		bool d_antialiasing;
 		bool autoScaleFonts;
+		QSize hidden_size;
 		bool d_scale_on_print, d_print_cropmarks;
 		int selectedAxis;
 		QStringList axesFormulas;
