@@ -84,18 +84,12 @@ void LayerButton::mouseDoubleClickEvent ( QMouseEvent * )
 	emit showCurvesDialog();
 }
 
-MultiLayer::MultiLayer(const QString& label, QWidget* parent, const QString name, Qt::WFlags f)
+MultiLayer::MultiLayer(const QString& label, QWidget* parent, const QString name, Qt::WindowFlags f)
 : MyWidget(label,parent,name,f)
 {
 	if ( name.isEmpty() )
 		setObjectName( "multilayer plot" );
 
-	QPalette pal = palette();
-	pal.setColor(QPalette::Active, QPalette::Window, QColor(Qt::white));
-	pal.setColor(QPalette::Inactive, QPalette::Window, QColor(Qt::white));
-	pal.setColor(QPalette::Disabled, QPalette::Window, QColor(Qt::white));
-	setPalette(pal);
-        
 	QDateTime dt = QDateTime::currentDateTime ();
 	setBirthDate(dt.toString(Qt::LocalDate));
 
@@ -114,18 +108,32 @@ MultiLayer::MultiLayer(const QString& label, QWidget* parent, const QString name
 
 	layerButtonsBox = new QHBoxLayout();
 	QHBoxLayout *hbox = new QHBoxLayout();
+	// add a zero width widget to reserve space for the layer's buttons
+	QWidget* strut = new QWidget();
+	strut->setFixedSize(0,LayerButton::btnSize());
+	hbox->addWidget(strut);
 	hbox->addLayout(layerButtonsBox);
 	hbox->addStretch();
 
 	canvas = new QWidget();
 	canvas->installEventFilter(this);
 
-	QVBoxLayout* layout = new QVBoxLayout(this);
+	QWidget* d_main_widget = new QWidget();
+	QVBoxLayout* layout = new QVBoxLayout();
+	d_main_widget->setLayout(layout);
 	layout->addLayout(hbox);
 	layout->addWidget(canvas, 1);
 	layout->setMargin(0);
 	layout->setSpacing(0);
-	setMinimumHeight(50);
+	this->setWidget(d_main_widget);
+
+	d_main_widget->setAutoFillBackground(true);
+	d_main_widget->setBackgroundRole(QPalette::Window);
+	QPalette pal = palette();
+	pal.setColor(QPalette::Window, QColor(Qt::white));
+	d_main_widget->setPalette(pal);
+
+	setMinimumSize(200,150);
     setGeometry(QRect( 0, 0, graph_width, graph_height ));
 	setFocusPolicy(Qt::StrongFocus);
 }
@@ -173,11 +181,6 @@ Graph* MultiLayer::addLayer(int x, int y, int width, int height)
 	return g;
 }
 
-void MultiLayer::adjustSize()
-{
-    canvas->resize(size().width(), size().height() - LayerButton::btnSize());
-}
-
 void MultiLayer::activateGraph(LayerButton* button)
 {
 	for (int i=0;i<buttonsList.count();i++)
@@ -682,7 +685,16 @@ void MultiLayer::exportVector(const QString& fileName, int, bool color, bool kee
   printer.setFullPage(true);
   printer.setOutputFileName(fileName);
   if (fileName.contains(".eps"))
+  {
+#if QT_VERSION >= 0x050000
+    QMessageBox::warning(this, tr("Warning"),
+      tr("Output in postscript format is not available for Qt5, using PDF"));
+    printer.setOutputFormat(QPrinter::PdfFormat);
+    printer.setOutputFileName(fileName+".pdf");
+#else
     printer.setOutputFormat(QPrinter::PostScriptFormat);
+#endif
+  }
 
   if (color)
     printer.setColorMode(QPrinter::Color);
@@ -737,7 +749,7 @@ void MultiLayer::exportPainter(QPainter &painter, bool keepAspect, QRect rect, Q
                  (double)size.height()/(double)rect.height()
                  );
 
-     painter.fillRect(rect, palette().brush(backgroundRole()));
+     painter.fillRect(rect, widget()->palette().brush(backgroundRole()));
 
      for (int i=0; i<(int)graphsList.count(); i++)
 	{
@@ -927,7 +939,7 @@ void MultiLayer::addTextLayer(int f, const QFont& font,
 	defaultTextMarkerColor = textCol;
 	defaultTextMarkerBackground = backgroundCol;
 
-	addTextOn=TRUE;
+	addTextOn=true;
 	QApplication::setOverrideCursor(Qt::IBeamCursor);
 	canvas->grabMouse();
 }
@@ -970,12 +982,6 @@ bool MultiLayer::eventFilter(QObject *object, QEvent *e)
 	{
 		resizeLayers((const QResizeEvent *)e);
 	}
-	else if (e->type()==QEvent::ContextMenu && object == titleBar)
-	{
-		emit showTitleBarMenu();
-		((QContextMenuEvent*)e)->accept();
-		return true;
-	}
 	return MyWidget::eventFilter(object, e);
 }
 
@@ -1035,7 +1041,7 @@ void MultiLayer::wheelEvent ( QWheelEvent * e )
 			if(yMouse>aux.y() && yMouse<(aux.y()+intSize.height()))
 			{
 				resize_graph=gr;
-				resize=TRUE;
+				resize=true;
 			}
 		}
 	}
@@ -1143,8 +1149,17 @@ QString MultiLayer::saveAsTemplate(const QString& geometryInfo)
 
 void MultiLayer::mousePressEvent ( QMouseEvent * e )
 {
+	if (!this->widget()->geometry().contains(e->pos())) { // event.pos is in titlebar
+		if (e->button() == Qt::RightButton) {
+			emit showTitleBarMenu();
+			e->accept();
+		} else {
+			MyWidget::mousePressEvent(e);
+		}
+		return;
+	}
 	int margin = 5;
-	QPoint pos = canvas->mapFromParent(e->pos());
+	QPoint pos = canvas->mapFrom(this,e->pos());
 	// iterate backwards, so layers on top are preferred for selection
 	QList<QWidget*>::iterator i = graphsList.end();
 	while (i!=graphsList.begin()) {
