@@ -48,9 +48,9 @@
 #include <QFontDialog>
 #include <QColorDialog>
 
-#include <qwtplot3d/qwt3d_color.h>
+#include <qwt3d_color.h>
 
-Plot3DDialog::Plot3DDialog( QWidget* parent, Qt::WFlags fl )
+Plot3DDialog::Plot3DDialog( QWidget* parent, Qt::WindowFlags fl )
     : QDialog( parent, fl )
 {
 	setWindowTitle( tr( "Surface Plot Options" ) );
@@ -834,7 +834,7 @@ bool Plot3DDialog::updatePlot()
 		try
 		{
 			MyParser parser;
-			parser.SetExpr(from.toAscii().constData());
+			parser.SetExpr(from.toUtf8().constData());
 			start=parser.Eval();
 		}
 		catch(mu::ParserError &e)
@@ -847,7 +847,7 @@ bool Plot3DDialog::updatePlot()
 		try
 		{
 			MyParser parser;
-			parser.SetExpr(to.toAscii().constData());
+			parser.SetExpr(to.toUtf8().constData());
 			end=parser.Eval();
 		}
 		catch(mu::ParserError &e)
