@@ -28,7 +28,7 @@
  ***************************************************************************/
 #include "PolynomFitDialog.h"
 #include "Graph.h"
-#include "ColorBox.h"
+#include "ColorButton.h"
 #include "ApplicationWindow.h"
 #include "PolynomialFit.h"
 
@@ -42,7 +42,7 @@
 #include <QLineEdit>
 #include <QComboBox>
 
-PolynomFitDialog::PolynomFitDialog( QWidget* parent, Qt::WFlags fl )
+PolynomFitDialog::PolynomFitDialog( QWidget* parent, Qt::WindowFlags fl )
 : QDialog( parent, fl )
 {
 	setWindowTitle(tr("Polynomial Fit Options"));
@@ -70,9 +70,9 @@ PolynomFitDialog::PolynomFitDialog( QWidget* parent, Qt::WFlags fl )
     gl1->addWidget(boxEnd, 3, 1);
 
     gl1->addWidget(new QLabel( tr("Color")), 4, 0);
-	boxColor = new ColorBox();
-	boxColor->setColor(QColor(Qt::red));
-    gl1->addWidget(boxColor, 4, 1);
+	btnColor = new ColorButton();
+	btnColor->setColor(QColor(Qt::red));
+	gl1->addWidget(btnColor, 4, 1);
 
 	boxShowFormula = new QCheckBox(tr( "Show Formula on Graph?" ));
 	boxShowFormula->setChecked( false );
@@ -93,8 +93,6 @@ PolynomFitDialog::PolynomFitDialog( QWidget* parent, Qt::WFlags fl )
 	hlayout->addWidget(gb1);
 	hlayout->addLayout(vl);
 
-	languageChange();
-
 	connect( buttonFit, SIGNAL( clicked() ), this, SLOT( fit() ) );
 	connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
 	connect( boxName, SIGNAL( activated(const QString&) ), this, SLOT(activateCurve(const QString&)));
@@ -117,7 +115,7 @@ void PolynomFitDialog::fit()
     PolynomialFit *fitter = new PolynomialFit(app, graph, boxOrder->value(), boxShowFormula->isChecked());
     if (fitter->setDataFromCurve(curveName, boxStart->text().toDouble(), boxEnd->text().toDouble()))
     {
-        fitter->setColor(boxColor->currentIndex());
+        fitter->setColor(btnColor->color());
         fitter->scaleErrors(app->fit_scale_errors);
         fitter->setOutputPrecision(app->fit_output_precision);
 		fitter->generateFunction(app->generateUniformFitPoints, app->fitPoints);
