@@ -38,6 +38,10 @@
 #include <QtCore>
 #include <QtGui>
 #include <QtDebug>
+#include <QMenu>
+#include <QInputDialog>
+#include <QFileDialog>
+#include <QProgressDialog>
 
 #include <stdlib.h>
 #include <math.h>
@@ -86,15 +90,15 @@ Matrix::Matrix()
 
 Matrix::~Matrix()
 {
-	delete d_view;
+  //  delete d_view.data();
 }
 
 void Matrix::setView(MatrixView * view)
 {
-	d_view = view; 
-	addActionsToView();
-	connect(d_view, SIGNAL(controlTabBarStatusChanged(bool)), this, SLOT(adjustTabBarAction(bool)));
-	adjustTabBarAction(true);
+  d_view = view; 
+  addActionsToView();
+  connect(d_view, SIGNAL(controlTabBarStatusChanged(bool)), this, SLOT(adjustTabBarAction(bool)));
+  adjustTabBarAction(true);
 }
 
 QWidget *Matrix::view()
@@ -744,6 +748,36 @@ void Matrix::addActionsToView()
 	d_view->addAction(action_add_rows);
 }
 
+void Matrix::translateActionsStrings()
+{
+	action_cut_selection->setText(tr("Cu&t"));
+	action_copy_selection->setText(tr("&Copy"));
+	action_paste_into_selection->setText(tr("Past&e"));
+	action_clear_selection->setText(tr("Clea&r","clear selection"));
+	action_set_formula->setText(tr("Assign &Formula"));
+	action_recalculate->setText(tr("Recalculate"));
+	action_select_all->setText(tr("Select All"));
+	action_clear_matrix->setText(tr("Clear Matrix"));
+	action_go_to_cell->setText(tr("&Go to Cell"));
+	action_transpose->setText(tr("&Transpose"));
+	action_mirror_horizontally->setText(tr("Mirror &Horizontally"));
+	action_mirror_vertically->setText(tr("Mirror &Vertically"));
+	action_import_image->setText(tr("&Import Image", "import image as matrix"));
+#ifndef LEGACY_CODE_0_2_x
+	action_duplicate->setText(tr("&Duplicate", "duplicate matrix"));
+#endif
+	action_dimensions_dialog->setText(tr("&Dimensions", "matrix size"));
+	action_edit_coordinates->setText(tr("Set &Coordinates"));
+	action_edit_format->setText(tr("Set Display &Format"));
+	action_insert_columns->setText(tr("&Insert Empty Columns"));
+	action_remove_columns->setText(tr("Remo&ve Columns"));
+	action_clear_columns->setText(tr("Clea&r Columns"));
+	action_add_columns->setText(tr("&Add Columns"));
+	action_insert_rows->setText(tr("&Insert Empty Rows"));
+	action_remove_rows->setText(tr("Remo&ve Rows"));
+	action_clear_rows->setText(tr("Clea&r Rows"));
+	action_add_rows->setText(tr("&Add Rows"));
+}
 
 bool Matrix::fillProjectMenu(QMenu * menu)
 {
@@ -769,6 +803,11 @@ bool Matrix::fillProjectMenu(QMenu * menu)
 	menu->addAction(action_import_image);
 	menu->addSeparator();
 	menu->addAction(action_go_to_cell);
+	if (action_clear_matrix->text() != tr("Clear Matrix"))
+	{
+		translateActionsStrings();
+		adjustTabBarAction(d_view->isControlTabBarVisible());
+	}
 
 	return true;
 
@@ -813,11 +852,11 @@ void Matrix::goToCell()
 	if (!d_view) return;
 	bool ok;
 
-	int col = QInputDialog::getInteger(0, tr("Go to Cell"), tr("Enter column"),
+	int col = QInputDialog::getInt(0, tr("Go to Cell"), tr("Enter column"),
 			1, 1, columnCount(), 1, &ok);
 	if ( !ok ) return;
 
-	int row = QInputDialog::getInteger(0, tr("Go to Cell"), tr("Enter row"),
+	int row = QInputDialog::getInt(0, tr("Go to Cell"), tr("Enter row"),
 			1, 1, rowCount(), 1, &ok);
 	if ( !ok ) return;
 
@@ -890,11 +929,11 @@ void Matrix::dimensionsDialog()
 {
 	bool ok;
 
-	int cols = QInputDialog::getInteger(0, tr("Set Matrix Dimensions"), tr("Enter number of columns"),
+	int cols = QInputDialog::getInt(0, tr("Set Matrix Dimensions"), tr("Enter number of columns"),
 			columnCount(), 1, 1e9, 1, &ok);
 	if ( !ok ) return;
 
-	int rows = QInputDialog::getInteger(0, tr("Set Matrix Dimensions"), tr("Enter number of rows"),
+	int rows = QInputDialog::getInt(0, tr("Set Matrix Dimensions"), tr("Enter number of rows"),
 			rowCount(), 1, 1e9, 1, &ok);
 	if ( !ok ) return;
 	
@@ -1202,7 +1241,7 @@ bool Matrix::readDisplayElement(XmlStreamReader * reader)
 		reader->raiseError(tr("invalid or missing numeric format"));
 		return false;
 	}
-	setNumericFormat(str.at(0).toAscii());
+	setNumericFormat(str.at(0).toLatin1());
 	
 	bool ok;
 	int digits = reader->readAttributeInt("displayed_digits", &ok);
