@@ -41,7 +41,7 @@
 #include <QLocale>
 #include <QDate>
 #include "Matrix.h"
-#include "ColorBox.h"
+#include "ColorButton.h"
 #include "MultiLayer.h"
 #include "Note.h"
 #include "Folder.h"
@@ -82,7 +82,7 @@ ImportOPJ::ImportOPJ(ApplicationWindow *app, const QString& filename) :
 		mw->setStatusBarText(QString());
 		if(filename.endsWith(".opj", Qt::CaseInsensitive))
 			createProjectTree(opj);
-		mw->showResults(opj.resultsLogString().c_str(), mw->logWindow->isVisible());
+		mw->showResults(opj.resultsLogString().c_str(), mw->logWindow.isVisible());
 	} catch(const std::logic_error& er){
 		QApplication::restoreOverrideCursor();
 		QMessageBox::critical(mw, "Origin Project Import Error", QString(er.what()));
@@ -100,7 +100,7 @@ bool ImportOPJ::createProjectTree(const OriginFile& opj)
 	tree<Origin::ProjectNode>::iterator root = projectTree->begin(projectTree->begin());
 	if(!root.node)
 		return false;
-	FolderListItem* item = (FolderListItem*)mw->folders->topLevelItem(0);
+	FolderListItem* item = (FolderListItem*)mw->folders.topLevelItem(0);
 	item->setText(0, root->name.c_str());
 	item->folder()->setName(root->name.c_str());
 	Folder* projectFolder = mw->projectFolder();
@@ -108,63 +108,62 @@ bool ImportOPJ::createProjectTree(const OriginFile& opj)
 	parent[root] = projectFolder;
 	for(tree<Origin::ProjectNode>::iterator sib = projectTree->begin(root); sib != projectTree->end(root); ++sib)
 	{
-		if(sib->type == Origin::ProjectNode::Folder){
-			Folder *f = new Folder(parent.value(projectTree->parent(sib)), sib->name.c_str());
-			parent[sib] = f;
-			f->setBirthDate(posixTimeToString(sib->creationDate));
-			f->setModificationDate(posixTimeToString(sib->modificationDate));
-			mw->addFolderListViewItem(f);
-			FolderListItem *fi = new FolderListItem(mw->current_folder->folderListItem(), f);
-			if (fi)
-				f->setFolderListItem(fi);
-		} else {
-			QString name = sib->name.c_str();
-			if(sib->type == Origin::ProjectNode::Note)
-			{
-				QRegExp rx("^@\\((\\S+)\\)$");
-				if(rx.indexIn(name) == 0)
-					name = rx.cap(1);
-			}
-			const char* nodetype;
-			switch (sib->type)
-			{
-				case Origin::ProjectNode::SpreadSheet:
-					nodetype = "Table";
-					break;
-				case Origin::ProjectNode::Matrix:
-					nodetype = "Matrix";
-					break;
-				case Origin::ProjectNode::Graph:
-					nodetype = "MultiLayer";
-					break;
-				case Origin::ProjectNode::Graph3D:
-					// there is no Graph3D type yet
-					nodetype = "MultiLayer"; // "Graph3D";
-					break;
-				case Origin::ProjectNode::Note:
-					nodetype = "Note";
-					break;
-				case Origin::ProjectNode::Excel:
-					// there is no Excel type yet
-					nodetype = "Table";
-					break;
-				default:
-					nodetype = "Unknown";
-					break;
-			}
-			MyWidget* w = projectFolder->window(name, nodetype);
-			while (w){ // Origin window names are unique, but we need to loop on all sheets of Excel windows
-				Folder *f = parent.value(projectTree->parent(sib));
-				if (f){
-					if (f==parent[root]) break; // skip windows that go to root folder
-					// removeWindow  uses QList.removeAll, so remove w before adding it to its folder
-					projectFolder->removeWindow(w);
-					f->addWindow(w);
-					f->setActiveWindow(w);
-				}
-				w = projectFolder->window(name, nodetype);
-			}
-		}
+          if(sib->type == Origin::ProjectNode::Folder){
+            
+            Folder& f = parent.value(projectTree->parent(sib))->addChild<Folder>(sib->name.c_str());
+            parent[sib] = &f;
+            f.setBirthDate(posixTimeToString(sib->creationDate));
+            f.setModificationDate(posixTimeToString(sib->modificationDate));
+            mw->addFolderListViewItem(&f);
+            f.setFolderListItem(new FolderListItem(mw->current_folder->folderListItem(), &f));
+          } else {
+            QString name = sib->name.c_str();
+            if(sib->type == Origin::ProjectNode::Note)
+              {
+                QRegExp rx("^@\\((\\S+)\\)$");
+                if(rx.indexIn(name) == 0)
+                  name = rx.cap(1);
+              }
+            const char* nodetype;
+            switch (sib->type)
+              {
+              case Origin::ProjectNode::SpreadSheet:
+                nodetype = "Table";
+                break;
+              case Origin::ProjectNode::Matrix:
+                nodetype = "Matrix";
+                break;
+              case Origin::ProjectNode::Graph:
+                nodetype = "MultiLayer";
+                break;
+              case Origin::ProjectNode::Graph3D:
+                // there is no Graph3D type yet
+                nodetype = "MultiLayer"; // "Graph3D";
+                break;
+              case Origin::ProjectNode::Note:
+                nodetype = "Note";
+                break;
+              case Origin::ProjectNode::Excel:
+                // there is no Excel type yet
+                nodetype = "Table";
+                break;
+              default:
+                nodetype = "Unknown";
+                break;
+              }
+            MyWidget* w = projectFolder->window(name, nodetype);
+            while (w){ // Origin window names are unique, but we need to loop on all sheets of Excel windows
+              Folder *f = parent.value(projectTree->parent(sib));
+              if (f){
+                if (f==parent[root]) break; // skip windows that go to root folder
+                // removeWindow  uses QList.removeAll, so remove w before adding it to its folder
+                projectFolder->removeWindow(w);
+                f->addWindow(w);
+                f->setActiveWindow(w);
+              }
+              w = projectFolder->window(name, nodetype);
+            }
+          }
 	}
 	mw->changeFolder(projectFolder, true);
 	return true;
@@ -199,288 +198,288 @@ int ImportOPJ::translateOrigin2ScidavisLineStyle(int linestyle) {
 // spreadsheets can be either in its own window or as a sheet in excels windows
 bool ImportOPJ::importSpreadsheet(const OriginFile &opj, const Origin::SpreadSheet &spread)
 {
-	static int visible_count=0;
-	QLocale locale = mw->locale();
-	int SciDAVis_scaling_factor=10; //in Origin width is measured in characters while in SciDAVis - pixels --- need to be accurate
-		int columnCount = spread.columns.size();
-		int maxrows = spread.maxRows;
-		if(!columnCount) //remove tables without cols
-			return false;
+  static int visible_count=0;
+  QLocale locale = mw->locale();
+  int SciDAVis_scaling_factor=10; //in Origin width is measured in characters while in SciDAVis - pixels --- need to be accurate
+  int columnCount = spread.columns.size();
+  int maxrows = spread.maxRows;
+  if(!columnCount) //remove tables without cols
+    return false;
 
-		Table *table = mw->newTable(spread.name.c_str(), maxrows, columnCount);
-		if (!table)
-			return false;
-		if (spread.hidden || spread.loose)
-			mw->hideWindow(table);
+  Table *table = mw->newTable(spread.name.c_str(), maxrows, columnCount);
+  if (!table)
+    return false;
+  if (spread.hidden || spread.loose)
+    mw->hideWindow(table);
 
-		table->setWindowLabel(spread.label.c_str());
-		for(int j = 0; j < columnCount; ++j){
-			Origin::SpreadColumn column = spread.columns[j];
-			Column *scidavis_column = table->column(j);
+  table->setWindowLabel(spread.label.c_str());
+  for(int j = 0; j < columnCount; ++j){
+    Origin::SpreadColumn column = spread.columns[j];
+    Column *scidavis_column = table->column(j);
 
-			QString name(column.name.c_str());
-			scidavis_column->setName(name.replace(QRegExp(".*_"),""));
-			if (column.command.size() > 0)
-				scidavis_column->setFormula(Interval<int>(0,maxrows), QString(column.command.c_str()));
-			scidavis_column->setComment(QString(column.comment.c_str()));
-			table->setColumnWidth(j, (int)column.width*SciDAVis_scaling_factor);
+    QString name(column.name.c_str());
+    scidavis_column->setName(name.replace(QRegExp(".*_"),""));
+    if (column.command.size() > 0)
+      scidavis_column->setFormula(Interval<int>(0,maxrows), QString(column.command.c_str()));
+    scidavis_column->setComment(QString(column.comment.c_str()));
+    table->setColumnWidth(j, (int)column.width*SciDAVis_scaling_factor);
 
-			switch(column.type){
-				case Origin::SpreadColumn::X:
-					table->setColPlotDesignation(j, SciDAVis::X);
-					break;
-				case Origin::SpreadColumn::Y:
-					table->setColPlotDesignation(j, SciDAVis::Y);
-					break;
-				case Origin::SpreadColumn::Z:
-					table->setColPlotDesignation(j, SciDAVis::Z);
-					break;
-				case Origin::SpreadColumn::XErr:
-					table->setColPlotDesignation(j, SciDAVis::xErr);
-					break;
-				case Origin::SpreadColumn::YErr:
-					table->setColPlotDesignation(j, SciDAVis::yErr);
-					break;
-				case Origin::SpreadColumn::Label:
-				default:
-					table->setColPlotDesignation(j, SciDAVis::noDesignation);
-			}
+    switch(column.type){
+    case Origin::SpreadColumn::X:
+      table->setColPlotDesignation(j, SciDAVis::X);
+      break;
+    case Origin::SpreadColumn::Y:
+      table->setColPlotDesignation(j, SciDAVis::Y);
+      break;
+    case Origin::SpreadColumn::Z:
+      table->setColPlotDesignation(j, SciDAVis::Z);
+      break;
+    case Origin::SpreadColumn::XErr:
+      table->setColPlotDesignation(j, SciDAVis::xErr);
+      break;
+    case Origin::SpreadColumn::YErr:
+      table->setColPlotDesignation(j, SciDAVis::yErr);
+      break;
+    case Origin::SpreadColumn::Label:
+    default:
+      table->setColPlotDesignation(j, SciDAVis::noDesignation);
+    }
 
-			QString format;
-			switch(column.valueType) {
-				case Origin::Numeric:
-				case Origin::TextNumeric:
-				/*
-				A TextNumeric column in Origin is a column whose filled cells contain either a double or a string.
-				In SciDAVis there is no equivalent column type.
-				Set the SciDAVis column type as 'Numeric' or 'Text' depending on the type of first element in column.
-				TODO: Add a "per column" flag, settable at import dialog, to choose between both types.
-				 */
-					{
-						double datavalue;
-						bool setAsText = false;
-						table->column(j)->setColumnMode(SciDAVis::Numeric);
-						for (int i=0; i < std::min((int)column.data.size(), maxrows); ++i) {
-							Origin::variant value(column.data[i]);
-							if (value.type() == Origin::variant::V_DOUBLE) {
-                                                          datavalue = value.as_double();
-								if (datavalue==_ONAN) continue; // mark for empty cell
-								if (!setAsText) {
-									scidavis_column->setValueAt(i, datavalue);
-								} else { // convert double to string for Text columns
-									scidavis_column->setTextAt(i, locale.toString(datavalue, 'g', 16));
-								}
-							} else { // string
-								if (!setAsText && i==0) {
-									table->column(j)->setColumnMode(SciDAVis::Text);
-									setAsText = true;
-								}
-								scidavis_column->setTextAt(i, column.data[i].as_string());
-							}
-						}
-						int f=0;
-						if(column.numericDisplayType == 0)
-						{
-							f=0;
-						}
-						else
-						{
-							switch(column.valueTypeSpecification)
-							{
-								case 0: //Decimal 1000
-									f=1;
-									break;
-								case 1: //Scientific
-									f=2;
-									break;
-								case 2: //Engeneering
-								case 3: //Decimal 1,000
-									f=0;
-									break;
-							}
-							Double2StringFilter *filter = static_cast<Double2StringFilter*>(table->column(j)->outputFilter());
-							filter->setNumericFormat(f);
-							filter->setNumDigits(column.decimalPlaces);
-						}
-						break;
-					}
-			case Origin::Text:
-				table->column(j)->setColumnMode(SciDAVis::Text);
-				for (int i=0; i < min((int)column.data.size(), maxrows); ++i) {
-                                  scidavis_column->setTextAt(i, column.data[i].as_string());
-				}
-				break;
-			case Origin::Date:
-				{
-					switch(column.valueTypeSpecification) {
-						case -128:
-							format="dd/MM/yyyy";
-							break;
-						case -119:
-							format="dd/MM/yyyy HH:mm";
-							break;
-						case -118:
-							format="dd/MM/yyyy HH:mm:ss";
-							break;
-						case 0:
-						case 9:
-						case 10:
-							format="dd.MM.yyyy";
-							break;
-						case 2:
-							format="MMM d";
-							break;
-						case 3:
-							format="M/d";
-							break;
-						case 4:
-							format="d";
-							break;
-						case 5:
-						case 6:
-							format="ddd";
-							break;
-						case 7:
-							format="yyyy";
-							break;
-						case 8:
-							format="yy";
-							break;
-						case 11:
-						case 12:
-						case 13:
-						case 14:
-						case 15:
-							format="yyMMdd";
-							break;
-						case 16:
-						case 17:
-							format="MMM";
-							break;
-						case 19:
-							format="M-d-yyyy";
-							break;
-						default:
-							format="dd.MM.yyyy";
-					}
-					for (int i=0; i < min((int)column.data.size(), maxrows); ++i)
-                                          scidavis_column->setValueAt(i, column.data[i].as_double());
-					table->column(j)->setColumnMode(SciDAVis::DateTime);
-					DateTime2StringFilter *filter = static_cast<DateTime2StringFilter*>(scidavis_column->outputFilter());
-					filter->setFormat(format);
-					break;
-				}
-			case Origin::Time:
-				{
-					switch(column.valueTypeSpecification + 128) {
-						case 0:
-							format="hh:mm";
-							break;
-						case 1:
-							format="hh";
-							break;
-						case 2:
-							format="hh:mm:ss";
-							break;
-						case 3:
-							format="hh:mm:ss.zzz";
-							break;
-						case 4:
-							format="hh ap";
-							break;
-						case 5:
-							format="hh:mm ap";
-							break;
-						case 6:
-							format="mm:ss";
-							break;
-						case 7:
-							format="mm:ss.zzz";
-							break;
-						case 8:
-							format="hhmm";
-							break;
-						case 9:
-							format="hhmmss";
-							break;
-						case 10:
-							format="hh:mm:ss.zzz";
-							break;
-					}
-					for (int i=0; i < min((int)column.data.size(), maxrows); ++i)
-                                          scidavis_column->setValueAt(i, column.data[i].as_double());
-					table->column(j)->setColumnMode(SciDAVis::DateTime);
-					DateTime2StringFilter *filter = static_cast<DateTime2StringFilter*>(table->column(j)->outputFilter());
-					filter->setFormat(format);
-					break;
-				}
-			case Origin::Month:
-				{
-					switch(column.valueTypeSpecification) {
-						case 0:
-							format = "MMM";
-							break;
-						case 1:
-							format = "MMMM";
-							break;
-						case 2:
-							format = "M";
-							break;
-					}
-					for (int i=0; i < min((int)column.data.size(), maxrows); ++i)
-                                          scidavis_column->setValueAt(i, column.data[i].as_double());
-					table->column(j)->setColumnMode(SciDAVis::Month);
-					DateTime2StringFilter *filter = static_cast<DateTime2StringFilter*>(table->column(j)->outputFilter());
-					filter->setFormat(format);
-					break;
-				}
-			case Origin::Day:
-				{
-					switch(column.valueTypeSpecification)
-					{
-						case 0:
-							format = "ddd";
-							break;
-						case 1:
-							format = "dddd";
-							break;
-						case 2:
-							format = "d";
-							break;
-					}
-					for (int i=0; i < min((int)column.data.size(), maxrows); ++i)
-                                          scidavis_column->setValueAt(i, column.data[i].as_double());
-					table->column(j)->setColumnMode(SciDAVis::Day);
-					DateTime2StringFilter *filter = static_cast<DateTime2StringFilter*>(table->column(j)->outputFilter());
-					filter->setFormat(format);
-					break;
-				}
-			default:
-				break;
-			}
-		}
+    QString format;
+    switch(column.valueType) {
+    case Origin::Numeric:
+    case Origin::TextNumeric:
+      /*
+        A TextNumeric column in Origin is a column whose filled cells contain either a double or a string.
+        In SciDAVis there is no equivalent column type.
+        Set the SciDAVis column type as 'Numeric' or 'Text' depending on the type of first element in column.
+        TODO: Add a "per column" flag, settable at import dialog, to choose between both types.
+      */
+      {
+        double datavalue;
+        bool setAsText = false;
+        table->column(j)->setColumnMode(SciDAVis::Numeric);
+        for (int i=0; i < std::min((int)column.data.size(), maxrows); ++i) {
+          Origin::variant value(column.data[i]);
+          if (value.type() == Origin::variant::V_DOUBLE) {
+            datavalue = value.as_double();
+            if (datavalue==_ONAN) continue; // mark for empty cell
+            if (!setAsText) {
+              scidavis_column->setValueAt(i, datavalue);
+            } else { // convert double to string for Text columns
+              scidavis_column->setTextAt(i, locale.toString(datavalue, 'g', 16));
+            }
+          } else { // string
+            if (!setAsText && i==0) {
+              table->column(j)->setColumnMode(SciDAVis::Text);
+              setAsText = true;
+            }
+            scidavis_column->setTextAt(i, column.data[i].as_string());
+          }
+        }
+        int f=0;
+        if(column.numericDisplayType == 0)
+          {
+            f=0;
+          }
+        else
+          {
+            switch(column.valueTypeSpecification)
+              {
+              case 0: //Decimal 1000
+                f=1;
+                break;
+              case 1: //Scientific
+                f=2;
+                break;
+              case 2: //Engeneering
+              case 3: //Decimal 1,000
+                f=0;
+                break;
+              }
+            Double2StringFilter *filter = static_cast<Double2StringFilter*>(table->column(j)->outputFilter());
+            filter->setNumericFormat(f);
+            filter->setNumDigits(column.decimalPlaces);
+          }
+        break;
+      }
+    case Origin::Text:
+      table->column(j)->setColumnMode(SciDAVis::Text);
+      for (int i=0; i < min((int)column.data.size(), maxrows); ++i) {
+        scidavis_column->setTextAt(i, column.data[i].as_string());
+      }
+      break;
+    case Origin::Date:
+      {
+        switch(column.valueTypeSpecification) {
+        case -128:
+          format="dd/MM/yyyy";
+          break;
+        case -119:
+          format="dd/MM/yyyy HH:mm";
+          break;
+        case -118:
+          format="dd/MM/yyyy HH:mm:ss";
+          break;
+        case 0:
+        case 9:
+        case 10:
+          format="dd.MM.yyyy";
+          break;
+        case 2:
+          format="MMM d";
+          break;
+        case 3:
+          format="M/d";
+          break;
+        case 4:
+          format="d";
+          break;
+        case 5:
+        case 6:
+          format="ddd";
+          break;
+        case 7:
+          format="yyyy";
+          break;
+        case 8:
+          format="yy";
+          break;
+        case 11:
+        case 12:
+        case 13:
+        case 14:
+        case 15:
+          format="yyMMdd";
+          break;
+        case 16:
+        case 17:
+          format="MMM";
+          break;
+        case 19:
+          format="M-d-yyyy";
+          break;
+        default:
+          format="dd.MM.yyyy";
+        }
+        for (int i=0; i < min((int)column.data.size(), maxrows); ++i)
+          scidavis_column->setValueAt(i, column.data[i].as_double());
+        table->column(j)->setColumnMode(SciDAVis::DateTime);
+        DateTime2StringFilter *filter = static_cast<DateTime2StringFilter*>(scidavis_column->outputFilter());
+        filter->setFormat(format);
+        break;
+      }
+    case Origin::Time:
+      {
+        switch(column.valueTypeSpecification + 128) {
+        case 0:
+          format="hh:mm";
+          break;
+        case 1:
+          format="hh";
+          break;
+        case 2:
+          format="hh:mm:ss";
+          break;
+        case 3:
+          format="hh:mm:ss.zzz";
+          break;
+        case 4:
+          format="hh ap";
+          break;
+        case 5:
+          format="hh:mm ap";
+          break;
+        case 6:
+          format="mm:ss";
+          break;
+        case 7:
+          format="mm:ss.zzz";
+          break;
+        case 8:
+          format="hhmm";
+          break;
+        case 9:
+          format="hhmmss";
+          break;
+        case 10:
+          format="hh:mm:ss.zzz";
+          break;
+        }
+        for (int i=0; i < min((int)column.data.size(), maxrows); ++i)
+          scidavis_column->setValueAt(i, column.data[i].as_double());
+        table->column(j)->setColumnMode(SciDAVis::DateTime);
+        DateTime2StringFilter *filter = static_cast<DateTime2StringFilter*>(table->column(j)->outputFilter());
+        filter->setFormat(format);
+        break;
+      }
+    case Origin::Month:
+      {
+        switch(column.valueTypeSpecification) {
+        case 0:
+          format = "MMM";
+          break;
+        case 1:
+          format = "MMMM";
+          break;
+        case 2:
+          format = "M";
+          break;
+        }
+        for (int i=0; i < min((int)column.data.size(), maxrows); ++i)
+          scidavis_column->setValueAt(i, column.data[i].as_double());
+        table->column(j)->setColumnMode(SciDAVis::Month);
+        DateTime2StringFilter *filter = static_cast<DateTime2StringFilter*>(table->column(j)->outputFilter());
+        filter->setFormat(format);
+        break;
+      }
+    case Origin::Day:
+      {
+        switch(column.valueTypeSpecification)
+          {
+          case 0:
+            format = "ddd";
+            break;
+          case 1:
+            format = "dddd";
+            break;
+          case 2:
+            format = "d";
+            break;
+          }
+        for (int i=0; i < min((int)column.data.size(), maxrows); ++i)
+          scidavis_column->setValueAt(i, column.data[i].as_double());
+        table->column(j)->setColumnMode(SciDAVis::Day);
+        DateTime2StringFilter *filter = static_cast<DateTime2StringFilter*>(table->column(j)->outputFilter());
+        filter->setFormat(format);
+        break;
+      }
+    default:
+      break;
+    }
+  }
 
 
 
-		if(!(spread.hidden || spread.loose) || opj.version() != 7.5){
-			table->showNormal();
+  if(!(spread.hidden || spread.loose) || opj.version() != 7.5){
+    table->showNormal();
 
-			//cascade the tables
-			if (opj.version() >= 6.0)
-		        {
-			   Origin::Rect windowRect;
-			   windowRect = spread.frameRect;
-			   table->parentWidget()->move(QPoint(windowRect.left, windowRect.top));
-			}
-			else {
-				int dx = table->verticalHeaderWidth();
-			        int dy=table->parentWidget()->frameGeometry().height() - table->height();
-			        table->parentWidget()->move(QPoint(visible_count*dx+xoffset*OBJECTXOFFSET,visible_count*dy));
-			   	visible_count++;
-			}
+    //cascade the tables
+    if (opj.version() >= 6.0)
+      {
+        Origin::Rect windowRect;
+        windowRect = spread.frameRect;
+        table->move(QPoint(windowRect.left, windowRect.top));
+      }
+    else {
+      int dx = table->verticalHeaderWidth();
+      int dy=table->frameGeometry().height() - table->height();
+      table->move(QPoint(visible_count*dx+xoffset*OBJECTXOFFSET,visible_count*dy));
+      visible_count++;
+    }
 
-		}
-	return true;
+  }
+  return true;
 }
 bool ImportOPJ::importTables(const OriginFile &opj)
 {
@@ -526,7 +525,7 @@ bool ImportOPJ::importTables(const OriginFile &opj)
 			int columnCount = layer.columnCount;
 			int rowCount = layer.rowCount;
 			mw->setStatusBarText(QString("Matrix %1 / %2, sheet %3 / %4").arg(s+1).arg(opj.matrixCount()).arg(l+1).arg(layers));
-			Matrix* Matrix = mw->newMatrix(matrix.name.c_str(), rowCount, columnCount);
+			Matrix* Matrix=mw->newMatrix(matrix.name.c_str(), rowCount, columnCount);
 			if (!Matrix)
 				return false;
 			Matrix->setWindowLabel(matrix.label.c_str());
@@ -573,12 +572,12 @@ bool ImportOPJ::importTables(const OriginFile &opj)
 			//cascade the matrices
 #if 0
 			int dx=Matrix->verticalHeaderWidth();
-			int dy=Matrix->parentWidget()->frameGeometry().height() - matrix->height();
+			int dy=Matrix->frameGeometry().height() - matrix->height();
 #endif
 // TODO
 			int dx = 100;
 			int dy = 100;
-			Matrix->parentWidget()->move(QPoint(visible_count*dx+xoffset*OBJECTXOFFSET,visible_count*dy));
+			Matrix->move(QPoint(visible_count*dx+xoffset*OBJECTXOFFSET,visible_count*dy));
 			visible_count++;
 
 		}
@@ -609,8 +608,8 @@ bool ImportOPJ::importNotes(const OriginFile &opj)
 
 		//cascade the notes
 		int dx=20;
-		int dy=note->parentWidget()->frameGeometry().height() - note->height();
-		note->parentWidget()->move(QPoint(visible_count*dx+xoffset*OBJECTXOFFSET,visible_count*dy));
+		int dy=note->frameGeometry().height() - note->height();
+		note->move(QPoint(visible_count*dx+xoffset*OBJECTXOFFSET,visible_count*dy));
 		visible_count++;
 	}
 	if(visible_count>0)
@@ -682,7 +681,7 @@ bool ImportOPJ::importGraphs(const OriginFile &opj)
 					continue;
 				}
 				QString tableName;
-				switch(data[0].toAscii())
+				switch(data[0].toLatin1())
 				{
 				case 'T':
 				case 'E':
@@ -693,7 +692,7 @@ bool ImportOPJ::importGraphs(const OriginFile &opj)
 						break;
 					if(style==Graph::ErrorBars)
 					{
-						int flags=_curve.symbolType;
+						int flags=_curve.symbolShape;
 						graph->addErrorBars(QString("%1_%2").arg(tableName, _curve.xColumnName.c_str()), table, QString("%1_%2").arg(tableName, _curve.yColumnName.c_str()),
 							((flags&0x10)==0x10?0:1), ceil(_curve.lineWidth), ceil(_curve.symbolSize), QColor(Qt::black),
 							(flags&0x40)==0x40, (flags&2)==2, (flags&1)==1);
@@ -746,7 +745,7 @@ bool ImportOPJ::importGraphs(const OriginFile &opj)
 				if((style==Graph::Scatter||style==Graph::LineSymbols)&&color==0xF7)//0xF7 -Automatic color
 					color=auto_color++;
 				cl.symCol=color;
-				switch(_curve.symbolType&0xFF)
+				switch(_curve.symbolShape)
 				{
 				case 0: //NoSymbol
 					cl.sType=0;
@@ -799,7 +798,7 @@ bool ImportOPJ::importGraphs(const OriginFile &opj)
 					cl.sType=0;
 				}
 
-				switch(_curve.symbolType>>8)
+				switch(_curve.symbolInterior)
 				{
 				case 0:
 					cl.fillCol=color;
@@ -820,7 +819,7 @@ bool ImportOPJ::importGraphs(const OriginFile &opj)
 				}
 
 				cl.lWidth = _curve.lineWidth;
-				color=_curve.lineColor.regular % ColorBox::numPredefinedColors();
+				color=_curve.lineColor.regular % ColorButton::colors_count;
 				cl.lCol = (_curve.lineColor.type==Origin::Color::Automatic?0:color); //0xF7 -Automatic color
 				int linestyle=_curve.lineStyle;
 				cl.filledArea=(_curve.fillArea || style==Graph::VerticalBars || style==Graph::HorizontalBars || style==Graph::Histogram || style == Graph::Pie || style == Graph::Box) ? 1 : 0;
@@ -956,13 +955,13 @@ bool ImportOPJ::importGraphs(const OriginFile &opj)
 			grid->enableY(!layer.yAxis.majorGrid.hidden);
 			grid->enableYMin(!layer.yAxis.minorGrid.hidden);
 
-			grid->setMajPenX(QPen(ColorBox::color(layer.xAxis.majorGrid.color), ceil(layer.xAxis.majorGrid.width),
+			grid->setMajPenX(QPen(ColorButton::color(layer.xAxis.majorGrid.color), ceil(layer.xAxis.majorGrid.width),
 							Graph::getPenStyle(translateOrigin2ScidavisLineStyle((Origin::GraphCurve::LineStyle)layer.xAxis.majorGrid.style))));
-			grid->setMinPenX(QPen(ColorBox::color(layer.xAxis.minorGrid.color), ceil(layer.xAxis.minorGrid.width),
+			grid->setMinPenX(QPen(ColorButton::color(layer.xAxis.minorGrid.color), ceil(layer.xAxis.minorGrid.width),
 						        Graph::getPenStyle(translateOrigin2ScidavisLineStyle((Origin::GraphCurve::LineStyle)layer.xAxis.minorGrid.style))));
-			grid->setMajPenY(QPen(ColorBox::color(layer.yAxis.majorGrid.color), ceil(layer.yAxis.majorGrid.width),
+			grid->setMajPenY(QPen(ColorButton::color(layer.yAxis.majorGrid.color), ceil(layer.yAxis.majorGrid.width),
 							Graph::getPenStyle(translateOrigin2ScidavisLineStyle((Origin::GraphCurve::LineStyle)layer.yAxis.majorGrid.style))));
-			grid->setMinPenY(QPen(ColorBox::color(layer.yAxis.minorGrid.color), ceil(layer.yAxis.minorGrid.width),
+			grid->setMinPenY(QPen(ColorButton::color(layer.yAxis.minorGrid.color), ceil(layer.yAxis.minorGrid.width),
 							Graph::getPenStyle(translateOrigin2ScidavisLineStyle((Origin::GraphCurve::LineStyle)layer.yAxis.minorGrid.style))));
 
 			grid->setAxis(2, 0);
@@ -1053,8 +1052,8 @@ bool ImportOPJ::importGraphs(const OriginFile &opj)
 
 				graph->showAxis(i, type, tableName, mw->table(tableName), !(formats[i].hidden),
 					tickTypeMap[formats[i].majorTicksType], tickTypeMap[formats[i].minorTicksType],
-					!(ticks[i].showMajorLabels),	ColorBox::color(formats[i].color), format, prec,
-					ticks[i].rotation, 0, "", (ticks[i].color==0xF7 ? ColorBox::color(formats[i].color) : ColorBox::color(ticks[i].color)));
+					!(ticks[i].showMajorLabels),	ColorButton::color(formats[i].color), format, prec,
+					ticks[i].rotation, 0, "", (ticks[i].color==0xF7 ? ColorButton::color(formats[i].color) : ColorButton::color(ticks[i].color)));
 			}
 
 
@@ -1065,8 +1064,8 @@ bool ImportOPJ::importGraphs(const OriginFile &opj)
 		if(!_graph.hidden)
 		{
 			int dx=20;
-			int dy=ml->parentWidget()->frameGeometry().height() - ml->height();
-			ml->parentWidget()->move(QPoint(visible_count*dx+xoffset*OBJECTXOFFSET,visible_count*dy));
+			int dy=ml->frameGeometry().height() - ml->height();
+			ml->move(QPoint(visible_count*dx+xoffset*OBJECTXOFFSET,visible_count*dy));
 			visible_count++;
 			ml->show();
 			ml->arrangeLayers(true,true);
