@@ -42,14 +42,97 @@ def import_to_global(modname, attrs=None, math=False):
 		mod = getattr(mod, submod)
 	if attrs==None: attrs=dir(mod)
 	for name in attrs:
-		f = getattr(mod, name)
-		setattr(__main__, name, f)
-		# make functions available in SciDAVis' math function list
-		if math and callable(f): __main__.scidavis.mathFunctions[name] = f
+		try:
+			f = getattr(mod, name)
+			setattr(__main__, name, f)
+			# make functions available in SciDAVis' math function list
+			if math and callable(f): __main__.scidavis.mathFunctions[name] = f
+		except AttributeError:
+			# ignore non available (or renamed) functions
+			pass
 
 # Import standard math functions and constants into global namespace.
 import_to_global("math", None, True)
 
+# make Qt API available (it gets imported in any case by the scidavis module)
+global QtGui, QtCore, Qt
+if (scidavis.app.qtVersion() >= 0x050000):
+	global QtWidgets
+	from PyQt5 import QtGui, QtWidgets, QtCore
+	from PyQt5.QtCore import Qt
+else:
+	from PyQt4 import QtGui, QtCore
+	from PyQt4.QtCore import Qt
+print("Using Qt", QtCore.QT_VERSION_STR)
+
+# import SciDAVis' classes to the global namespace (particularly useful for fits)
+for name in dir(__main__.scidavis):
+	setattr(__main__, name, getattr(__main__.scidavis, name))
+
+# import selected methods of ApplicationWindow into the global namespace
+appImports = (
+	"table", "newTable",
+	"matrix", "newMatrix",
+	"graph", "newGraph",
+	"note", "newNote",
+	"plot", "plotContour", "plotColorMap", "plotGrayScale",
+	"activeFolder", "rootFolder", "saveFolder",
+	"renameWindow", "clone",
+	"importImage"
+	)
+for name in appImports:
+	setattr(__main__,name,getattr(__main__.scidavis.app,name))
+
+# make Y columns indexable (using lookup in corresponding X column)
+def __column_getitem(self, index):
+  if self.plotDesignation() != "Y":
+    return None
+  x = self.x()
+  for row in range(self.rowCount()):
+      if x.columnMode() == "Numeric":
+          xval = x.valueAt(row)
+      elif x.columnMode() == "Text":
+          xval = x.textAt(row)
+      else:
+          xval = x.dateTimeAt(row)
+      if xval == index:
+          if self.columnMode() == "Numeric":
+              return self.valueAt(row)
+          elif self.columnMode() == "Text":
+              return self.textAt(row)
+          else:
+              return self.dateTimeAt(row)
+__main__.scidavis.Column.__getitem__ = __column_getitem
+
+def __column_setitem(self, index, value):
+  if self.plotDesignation() != "Y":
+    return None
+  x = self.x()
+  for row in range(x.rowCount()):
+      if x.columnMode() == "Numeric":
+          xval = x.valueAt(row)
+      elif x.columnMode() == "Text":
+          xval = x.textAt(row)
+      else:
+          xval = x.dateTimeAt(row)
+      if xval == index:
+          if self.columnMode() == "Numeric":
+              return self.setValueAt(row, value)
+          elif self.columnMode() == "Text":
+              return self.setTextAt(row, value)
+          else:
+              return self.setDateTimeAt(row, value)
+__main__.scidavis.Column.__setitem__ = __column_setitem
+
+# import utility module
+import sys
+sys.path.append(".")
+try:
+	import_to_global("scidavisUtil")
+	print("scidavisUtil successfully imported")
+except(ImportError): 
+	print("failed to import scidavisUtil")
+
 # Import selected parts of scipy.special (if available) into global namespace.
 # See www.scipy.org for information on SciPy and how to get it.
 have_scipy = False
@@ -76,7 +159,10 @@ try:
 		# Derivatives of Bessel Functions
 		"jvp", "yvp", "kvp", "ivp", "h1vp", "h2vp",
 		# Spherical Bessel Functions
+		# scipy version < 1.0.0
 		"sph_jn", "sph_yn", "sph_jnyn", "sph_in", "sph_kn", "sph_inkn",
+		# scipy version >= 1.0.0
+		"spherical_jn", "spherical_yn", "spherical_in", "spherical_kn",
 		# Ricatti-Bessel Functions
 		"riccati_jn", "riccati_yn",
 		# Struve Functions
@@ -246,83 +332,3 @@ try:
 		import_to_global("pygsl.sf", special_functions_doublets, True)
 		print("Loaded %d special functions from pygsl.sf." % (len(special_functions) + len(special_functions_doublets)))
 except(ImportError): pass
-
-
-# make Qt API available (it gets imported in any case by the scidavis module)
-global QtGui
-from PyQt4 import QtGui
-
-global QtCore
-from PyQt4 import QtCore
-
-global Qt
-from PyQt4.QtCore import Qt
-
-# import SciDAVis' classes to the global namespace (particularly useful for fits)
-for name in dir(__main__.scidavis):
-	setattr(__main__, name, getattr(__main__.scidavis, name))
-
-# import selected methods of ApplicationWindow into the global namespace
-appImports = (
-	"table", "newTable",
-	"matrix", "newMatrix",
-	"graph", "newGraph",
-	"note", "newNote",
-	"plot", "plotContour", "plotColorMap", "plotGrayScale",
-	"activeFolder", "rootFolder", "saveFolder",
-	"renameWindow", "clone",
-	"importImage"
-	)
-for name in appImports:
-	setattr(__main__,name,getattr(__main__.scidavis.app,name))
-
-# make Y columns indexable (using lookup in corresponding X column)
-def __column_getitem(self, index):
-  if self.plotDesignation() != "Y":
-    return None
-  x = self.x()
-  for row in range(self.rowCount()):
-      if x.columnMode() == "Numeric":
-          xval = x.valueAt(row)
-      elif x.columnMode() == "Text":
-          xval = x.textAt(row)
-      else:
-          xval = x.dateTimeAt(row)
-      if xval == index:
-          if self.columnMode() == "Numeric":
-              return self.valueAt(row)
-          elif self.columnMode() == "Text":
-              return self.textAt(row)
-          else:
-              return self.dateTimeAt(row)
-__main__.scidavis.Column.__getitem__ = __column_getitem
-
-def __column_setitem(self, index, value):
-  if self.plotDesignation() != "Y":
-    return None
-  x = self.x()
-  for row in range(x.rowCount()):
-      if x.columnMode() == "Numeric":
-          xval = x.valueAt(row)
-      elif x.columnMode() == "Text":
-          xval = x.textAt(row)
-      else:
-          xval = x.dateTimeAt(row)
-      if xval == index:
-          if self.columnMode() == "Numeric":
-              return self.setValueAt(row, value)
-          elif self.columnMode() == "Text":
-              return self.setTextAt(row, value)
-          else:
-              return self.setDateTimeAt(row, value)
-__main__.scidavis.Column.__setitem__ = __column_setitem
-
-# import utility module
-import sys
-sys.path.append(".")
-try:
-	import_to_global("scidavisUtil")
-	print("scidavisUtil successfully imported")
-except(ImportError): 
-	print("failed to import scidavisUtil")
-
